@@ -378,6 +378,7 @@ class LogstashHandler(logging.Handler):
     def emit(self, record: logging.LogRecord) -> None:
         if not self.log_server:
             return
+        send_data = None
         try:
             send_data = self.get_send_data(record=record)
             self.send(send_data=send_data)
@@ -386,7 +387,7 @@ class LogstashHandler(logging.Handler):
             raise
         except Exception as e:
             if sys.stderr:
-                sys.stderr.write(f"error in send to logstash {self.log_server}. e: {e}")
+                sys.stderr.write(f"error in send to logstash {self.log_server}. e: {e}, send_data: {send_data}")
 
 
 class ColorfulStreamHandler(logging.StreamHandler):
